@@ -1,8 +1,9 @@
-import time
-import pdb
-# from gi.repository import Notify
+import time, pdb
 from subprocess import call
 
+seconds_listen_channel = 5*60 # seconds
+my_username = u"fenton"
+
 monitored_channels = {} # "channel_name": time_i_last_chatted
 
 def generate_actions_from_irc_message(args):
@@ -48,24 +49,36 @@ def generate_actions_from_irc_message(args):
 
 # This method dispatches to the required action.  Each action takes a
 # hash/dict as an argument, this contains the actual arguments.
-def perform_actions(action_list):
+def perform_actions(action_list, printer):
     for action in action_list:
         function = action[u"action"]
         arguments = action[u"arguments"]
-        function(arguments)
+        function(arguments, printer)
 
 #######################
 # THE ACTIONS
 
-def display_alert(args):
+def display_alert(args,printer):
     alert_title = args[u'alert_title']
     alert_message = args[u'alert_message']
     urgency = args[u'urgency']
     # msg=Notify.Notification.new (alert_title, alert_message, u"dialog-information")
     # msg.show ()
     cmd = construct_notification_command(alert_title, alert_message, urgency)
-#    pdb.set_trace()
+    #    pdb.set_trace()
+    printer ("The Command:", str(cmd))
     call(cmd)    
+    
+def play_sound(args,printer):
+    a = 1
+    #filename = u"~/bin/sounds/" + args[u'sound_file'] + u".ogg"    
+    cmd = [u"play", u"-q", filename]
+    printer ("The Command:", str(cmd))
+    #call(cmd)
+
+
+##########################
+## HELPERS
 
 def monitored_channel(channel, monitored_channels):
     for mon_channel, last_chatted in monitored_channels.items():
@@ -75,15 +88,6 @@ def monitored_channel(channel, monitored_channels):
                 return True
     return False
 
-    
-def play_sound(args):
-    a = 1
-    #filename = u"~/bin/sounds/" + args[u'sound_file'] + u".ogg"    
-    #call([u"play", u"-q", filename])    
-
-
-##########################
-## HELPERS
 
 def construct_alert(frm, channel, msg, elapsed=None):
     alert_title = frm + u"@" + channel + u":"
@@ -130,11 +134,6 @@ def init(args): # in_my_username, in_seconds_listen_channel):
 
 # Notify.init (u"Notify Init")
 
-seconds_listen_channel = 5*60 # seconds
-my_username = u"fenton"
-
-
-#### HELPERS
 
 def display_actions(actions):
     print( "RESPONSE:" )
